@@ -71,9 +71,8 @@ class Package:
                                   self._signature.channel)
 
     def create(self, configuration=BuilderSettings()):
-        pattern=self.get_pattern()
-        print(f"{configuration.host_profile}")
-        profile_build = ProfileData(profiles=[f"{configuration.build_profile}"],settings="",
+        pattern=self.get_pattern() 
+        profile_build = ProfileData(profiles=[f"{configuration.build_profile}"],settings=configuration.convert_build_settings_str(),
                                     options="", env="")
         self.conanfactory.create(self.path,
                                   name=self.name,
@@ -83,6 +82,7 @@ class Package:
                                   profile_names=[f"{configuration.host_profile}"],
                                   profile_build=profile_build,
                                   settings=configuration.host_settings,
+                                  build_modes=[f"{configuration.build}"],
                                   test_build_folder=f'/tmp/{pattern}/tbf')
 
     def source(self):
